==> centreon-web-23.04.29.tar.gz: centreon-web-23.04.29/src/Centreon/Application/DataRepresenter/Listing.php <==
<?php

/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 *
 */

namespace Centreon\Application\DataRepresenter;

use JsonSerializable;
use Centreon\Application\DataRepresenter\Entity;

/**
 * @OA\Schema(
 *   schema="Pagination",
 *   allOf={
 *     @OA\Schema(
 *       @OA\Property(property="total", type="integer"),
 *       @OA\Property(property="offset", type="integer"),
 *       @OA\Property(property="limit", type="integer")
 *     )
 *   }
 * )
 */
class Listing implements JsonSerializable
{
    /**
     * @var array
     */
    private $entities;

    /**
     * @var int
     */
    private $offset;

    /**
     * @var int
     */
    private $limit;

    /**
     * @var int
     */
    private $total;

    /**
     * @var string
     */
    private $entityClass;

    /**
     * Construct
     *
     * @param mixed $entities
     * @param string $entityClass Entity JSON wrap class
     * @param int $total
     * @param int $offset
     * @param int $limit
     * @param string $entityClass
     */
    public function __construct(
        $entities,
        int $total = null,
        int $offset = null,
        int $limit = null,
        string $entityClass = null
    ) {
        $this->entities = $entities ?? [];
        $this->total = $total ? $total : count($this->entities);
        $this->offset = $offset;
        $this->limit = $limit !== null ? $limit : $this->total;
        $this->entityClass = $entityClass ?? Entity::class;
    }

    /**
     * JSON serialization of list
     *
     * @return array<string,mixed>
     */
    public function jsonSerialize(): mixed
    {
        $result = [
            'pagination' => [
                'total' => $this->total,
                'offset' => $this->offset !== null ? $this->offset : 0,
                'limit' => $this->limit,
            ],
            'entities' => [],
        ];

        foreach ($this->entities as $entity) {
            $result['entities'][] = new $this->entityClass($entity);
        }

        return $result;
    }
}

==> centreon-web-24.10.15.tar.gz: centreon-web-24.10.15/src/Centreon/Application/DataRepresenter/Listing.php <==
<?php

/*
 * Copyright 2005-2019 Centreon
 * Centreon is developed by : Julien Mathis and Romain Le Merlus under
 * GPL Licence 2.0.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation ; either version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see <http://www.gnu.org/licenses>.
 *
 * Linking this program statically or dynamically with other modules is making a
 * combined work based on this program. Thus, the terms and conditions of the GNU
 * General Public License cover the whole combination.
 *
 * As a special exception, the copyright holders of this program give Centreon
 * permission to link this program with independent modules to produce an executable,
 * regardless of the license terms of these independent modules, and to copy and
 * distribute the resulting executable under terms of Centreon choice, provided that
 * Centreon also meet, for each linked independent module, the terms  and conditions
 * of the license of that module. An independent module is a module which is not
 * derived from this program. If you modify this program, you may extend this
 * exception to your version of the program, but you are not obliged to do so. If you
 * do not wish to do so, delete this exception statement from your version.
 *
 * For more information : contact@centreon.com
 *
 *
 */

namespace Centreon\Application\DataRepresenter;

use JsonSerializable;
use Centreon\Application\DataRepresenter\Entity;

/**
 * @OA\Schema(
 *   schema="Pagination",
 *   allOf={
 *     @OA\Schema(
 *       @OA\Property(property="total", type="integer"),
 *       @OA\Property(property="offset", type="integer"),
 *       @OA\Property(property="limit", type="integer")
 *     )
 *   }
 * )
 */
class Listing implements JsonSerializable
{
    /**
     * @var array
     */
    private $entities;

    /**
     * @var int|null
     */
    private $offset;

    /**
     * @var int
     */
    private $limit;

    /**
     * @var int
     */
    private $total;

    /**
     * @var string
     */
    private $entityClass;

    /**
     * Construct
     *
     * @param mixed $entities
     * @param string $entityClass Entity JSON wrap class
     * @param int $total
     * @param int $offset
     * @param int $limit
     * @param string $entityClass
     */
    public function __construct(
        $entities,
        int $total = null,
        int $offset = null,
        int $limit = null,
        string $entityClass = null
    ) {
        $this->entities = $entities ?? [];
        $this->total = $total ?: count($this->entities);
        $this->offset = $offset;
        $this->limit = $limit ?? $this->total;
        $this->entityClass = $entityClass ?? Entity::class;
    }

    /**
     * JSON serialization of list
     *
     * @return array<string,mixed>
     */
    public function jsonSerialize(): mixed
    {
        $result = [
            'pagination' => [
                'total' => $this->total,
                'offset' => $this->offset ?? 0,
                'limit' => $this->limit,
            ],
            'entities' => [],
        ];

        foreach ($this->entities as $entity) {
            $result['entities'][] = new $this->entityClass($entity);
        }

        return $result;
    }
}
